@@ -156,7 +156,7 @@ xb_mysql_connect()
 	}
 
 #if !defined(DONT_USE_MYSQL_PWD)
-	if (!opt_password)
+	if (!opt_password || !strlen(opt_password))
 	{
 		opt_password=getenv("MYSQL_PWD");
 	}
@@ -459,9 +459,12 @@ bool get_mysql_vars(MYSQL *connection)
 
   msg("Using server version %s", version_var);
 
-  if (!(ret= detect_mysql_capabilities_for_backup()))
+  if (opt_galera_info && !have_galera_enabled)
   {
-    goto out;
+    msg("--galera-info is specified on the command "
+        "line, but the server does not support Galera "
+        "replication. Ignoring the option.");
+    opt_galera_info= false;
   }
 
   /* make sure datadir value is the same in configuration file */
@@ -554,30 +557,6 @@ out:
   return (ret);
 }
 
-/*********************************************************************//**
-Query the server to find out what backup capabilities it supports.
-@return	true on success. */
-bool
-detect_mysql_capabilities_for_backup()
-{
-	/* do some sanity checks */
-	if (opt_galera_info && !have_galera_enabled) {
-		msg("--galera-info is specified on the command "
-		 	"line, but the server does not support Galera "
-		 	"replication. Ignoring the option.");
-		opt_galera_info = false;
-	}
-
-	if (opt_slave_info && have_multi_threaded_slave &&
-	    !have_gtid_slave) {
-	    	msg("The --slave-info option requires GTID enabled for a "
-			"multi-threaded slave.");
-		return(false);
-	}
-
-	return(true);
-}
-
 static
 bool
 select_incremental_lsn_from_history(lsn_t *incremental_lsn)
@@ -1916,7 +1895,7 @@ bool write_backup_config_file(ds_ctxt *datasink)
 		srv_log_file_size,
 		srv_page_size,
 		srv_undo_dir,
-                (uint) srv_undo_tablespaces,
+		srv_undo_tablespaces,
 		page_zip_level,
 		innobase_buffer_pool_filename ?
 			"innodb_buffer_pool_filename=" : "",
